@@ -214,7 +214,7 @@ class curse():
             db = await aiosqlite.connect("curse.db")
             await db.execute("DELETE FROM curses WHERE guild = ?", (guildid,))
             await db.commit()
-            await ctx.send("Cleraed all curses from this server", delete_after=7)
+            await ctx.send("Cleared all curses from this server", delete_after=7)
             await db.close()
         except:
             await ctx.send("There is not a curse list for this guild. Create one by doing !addword followed by a list of words or a single word.", delete_after=10)
@@ -540,7 +540,8 @@ class rr():
         msg_id TEXT,
         emoji UNICODE,
         role TEXT,
-        guild TEXT
+        guild TEXT,
+        channel TEXT
         )""")
         await db.commit()
         embed = discord.Embed(title = title, color = 0x0000FF, description = description)
@@ -559,7 +560,7 @@ class rr():
                 role = role.replace("&", "")
                 number += 1
                 await msg.add_reaction(x)
-                await db.execute("INSERT INTO rr (msg_id,emoji,role,guild) VALUES (?,?,?,?)", (str(msg.id),x,str(role),str(ctx.guild.id)))
+                await db.execute("INSERT INTO rr (msg_id,emoji,role,guild,channel) VALUES (?,?,?,?,?)", (str(msg.id),x,str(role),str(ctx.guild.id),str(ctx.channel.id)))
             await db.commit()
             await db.close()
         else:
@@ -568,7 +569,7 @@ class rr():
             role = role.replace(">", "")
             role = role.replace("@", "")
             role = role.replace("&", "")
-            await db.execute("INSERT INTO rr (msg_id,emoji,role,guild) VALUES (?,?,?,?)", (str(msg.id),emoji,str(role),str(ctx.guild.id)))
+            await db.execute("INSERT INTO rr (msg_id,emoji,role,guild,channel) VALUES (?,?,?,?,?)", (str(msg.id),emoji,str(role),str(ctx.guild.id),str(ctx.channel.id)))
             await db.commit()
             await db.close()
 
@@ -597,11 +598,44 @@ class rr():
                     await member.remove_roles(role)
         await db.close()
 
-    async def clear(ctx, dir):
+    async def clear_all(ctx, dir):
         os.chdir(dir)
         guild = str(ctx.guild.id)
         db = await aiosqlite.connect("rr.db")
         await db.execute("DELETE FROM rr WHERE guild = ?", (guild,))
         await db.commit()
         await db.close()
-        await ctx.send("Delted all reaction role info for this server.", delete_after=7)
\ No newline at end of file
+        await ctx.send("Delted all reaction role info for this server.", delete_after=7)
+
+    async def clear_one(ctx, dir, message_id):
+        os.chdir(dir)
+        guild = str(ctx.guild.id)
+        message_id = str(message_id)
+        db = await aiosqlite.connect("rr.db")
+        await db.execute("DELETE FROM rr WHERE guild = ? and msg_id = ?", (guild,message_id))
+        await db.commit()
+        await db.close()
+        await ctx.send(f"Delted reaction role info for {message_id}", delete_after=7)
+    async def display(ctx, dir):
+        os.chdir(dir)
+        guild = str(ctx.guild.id)
+        db = await aiosqlite.connect("rr.db")
+        embed = discord.Embed(title="Reaction Roles", color = 0x0000FF)
+        async with db.execute("SELECT msg_id FROM rr GROUP BY msg_id") as cursor:
+            number = 0
+            async for entry in cursor:
+                number += 1
+                async with db.execute("SELECT role,emoji,channel FROM rr WHERE guild = ? and msg_id = ?", (guild,entry[0])) as f:
+                    msg = ""
+                    async for entry in f:
+                        print(entry)
+                        role,emoji,channel = entry
+                        channel = ctx.guild.get_channel(int(channel))
+                        role = ctx.guild.get_role(int(role))
+                        msg += f"Emoji: {emoji} Role: {role.mention} Channel: #{channel} Message ID: {entry[0]}\n"
+                embed.add_field(name=f"Reaction Role #{number}", inline=False, value=msg)
+        if number > 0:
+            await ctx.send(embed=embed, reference= ctx.message.reference or ctx.message)
+        else:
+            await ctx.send("There are no reaction roles in this server.", delete_after=5)
+        await db.close()
